<?php

namespace App\Http\Controllers\adminpanel;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\User;
use Validator;
use Illuminate\Pagination\Paginator;

class UserController extends Controller
{
    private $pagination = 10;

    public function manage() {
        $data = User::where('is_active', '!=', 0)->paginate($this->pagination);
        return view('adminpanel.manageuser', compact('data'));

    }
    public function add() {
        $data = array('type'=>'add');
        return view('adminpanel.adduser', compact('data'));
    }

    public function save(Request $request) {
       
        $input = $request->all();
        $validator = Validator::make( $input, $this->getRules('Add', $input), $this->messages());
        if ($validator->fails()) {
            $data = array('type'=>'add', 'input'=>$input, 'error'=>$validator->messages());
            return view('adminpanel.adduser', compact('data'));
            exit();
        }
        if(isset($input["profile_picture"])) 
        {
            $imagePath = $input["profile_picture"];
            $extension  = pathinfo($imagePath->getClientOriginalName(), PATHINFO_EXTENSION);
            
            $filename = time()."profile_picture.".$extension;
            $upload_dir_path = public_path()."/uploads/profile_picture";
            $imagePath->move($upload_dir_path, $filename );  
            $input['profile_picture'] = $filename;          
        }
        $input['password'] = bcrypt($input['password']);
        $user = User::create($input);
        if($user->id>0) {
            return redirect()->route('adminpanel.user.manage')->with('success', 'User Created successfully.');
        } else {
            return redirect()->route('adminpanel.user.add')->withErrors(['Error creating record. Please try again.']);
        }
    }

	public function edit($id) {
        $input = User::where('id', '=', $id)->get();
        $data = array('type'=>'Edit', 'input'=>$input);
	    return view('adminpanel.adduser', compact('data'));
	}

	public function update(Request $request) {
		$input = $request->all();
        $id = $input['id'];
        $validator = Validator::make( $input, $this->getRules('Edit', $input), $this->messages());

        if ($validator->fails()) {
            $data = array('type'=>'Edit', 'input'=>$input, 'error'=>$validator->messages());
            return view('adminpanel.adduser', compact('data'));
            exit();
        }      
        $update = array();
        $update["first_name"] = $input['first_name'];
        $update["last_name"] = $input['last_name'];
        $update["email"] = $input['email'];
        $update["contact_number"] = $input['contact_number'];
        $update["gender"] = $input['gender'];
        $update["dob"] = $input['dob'];
        if(isset($input["profile_picture"])) 
        {
            $imagePath = $input["profile_picture"];
            $extension  = pathinfo($imagePath->getClientOriginalName(), PATHINFO_EXTENSION);
            
            $filename = time()."profile_picture.".$extension;
            $upload_dir_path = public_path()."/uploads/profile_picture";
            $imagePath->move($upload_dir_path, $filename );  
            $update['profile_picture'] = $filename;          
        }
        if(isset($input['password'])) {
            $update["password"] = bcrypt($input['password']);
        }
        $user = User::where('id', '=', $id)->update($update);
        return redirect()->route('adminpanel.user.manage')->with('success', 'User Updated successfully.');

	}

    public function delete($id)
    {
        
        $update = array();
        $update["is_active"] = '0';

        $user = User::where('id', '=', $id)->update($update);

        return redirect()->route('adminpanel.user.manage')->with('success', 'User Deleted successfully.');
    }
    public function search(Request $request) {
        $input = $request->all();
        $qry = User::query();
        if(trim($input["search"])!="") {
            $search = trim($input["search"]);
            $qry->where([
                ["first_name", "like", "%{$search}%"],
            ]);
            $search = $input["search"];
            
            $qry->orwhere([
                ["last_name", "like", "%{$search}%"],
            ]);
            $qry->orwhere([
                ["email", "like", "%{$search}%"],
            ]);
        }
        $data = $qry->paginate($this->pagination);
        $data->appends($input);
        return view('adminpanel.manageuser', compact('data'));
    }

    public function block($id)
    {
        $update = array();
        $update["is_active"] = '2';

        $user = User::where('id', '=', $id)->update($update);
        return redirect()->route('adminpanel.user.manage')->with('success', 'User Block successfully.');
    }

    public function unblock($id)
    {
        $update = array();
        $update["is_active"] = '1';

        $user = User::where('id', '=', $id)->update($update);
        return redirect()->route('adminpanel.user.manage')->with('success', 'User Un Block successfully.');
    }

	private function getRules($type, $input) {
        $return = array();
        $return['first_name'] = 'required|max:30';
        $return['last_name'] = 'required|max:30';
        $return['email'] = 'required|email|max:100';
        $return['gender'] = 'required';
        $return['dob'] = 'required|date';
     
        if($type != 'Edit'){
            $return['password'] = 'required|max:20';
        }
       
        return $return;
    }

    private function messages() {
        return [
            'first_name.required'  => $this->getRequiredMessage('first name'),
            'first_name.max'  => $this->getGreaterMessage('first name', 30),
            'last_name.required'  => $this->getRequiredMessage('last name'),
            'last_name.max'  => $this->getGreaterMessage('last name', 30),
            'email.required'  => $this->getRequiredMessage('email'),
            'email.max'  => $this->getGreaterMessage('email ', 100),
            'gender.required'  => $this->getRequiredMessage('gender'),
            'dob.required'  => $this->getRequiredMessage('dob'),
            'password.required'  => $this->getRequiredMessage('password'),
  
        ];
    }

    private function getRequiredMessage($string) {
        return 'The ' . $string . ' field is required.';
    }

    private function getGreaterMessage($string, $maxchar) {
        return 'The ' . $string . ' may not be greater than ' . $maxchar . ' characters.';
    }

}
