<?php

namespace App\Http\Controllers\front;

use App\Http\Controllers\Controller;
use App\Models\CompanyLogo;
use App\Models\Plan;
use App\Models\S3Upload;
use App\Models\FAQCategory;
use Illuminate\Http\Request;
use Illuminate\Http\Response;
use Illuminate\Http\RedirectResponse;
use App\Models\Staticpage;
use Illuminate\Support\Facades\Mail;
use App\Models\Recaptcha;
use App\Mail\ContactFormMail;
use App\Mail\BecomeARetailer;
use App\Models\Setting;
use App\Services\MailchimpService;
use Exception;

class StaticpageController extends Controller
{
    /*
    Staticpage Id = page
    1   =   About Us
    2   =   Contact Us
    3   =   Privacy Policy
    4   =   Cookie Policy
    5   =   FAQ
    6   =   Terms & Condition
    7   =   Home Page
    */
    public function home(Request $request)
    {

        $data = Staticpage::find(7);
        $plans = Plan::where('is_hidden', '0')->where('is_upgradePlan', '0')->where('is_B2B', '0')->get();
        $companyLogos   =   CompanyLogo::get();
        return view('front.index', compact('plans', 'companyLogos', 'data'));
    }

    function aboutus(Request $request)
    {
        return view('front.aboutus');
    }

    function privacyPolicy(Request $request)
    {
        $data = Staticpage::find(3);
        return view('front.privacy-policy', compact('data'));
    }

    function termsOfUse(Request $request)
    {
        $data = Staticpage::find(6);
        return view('front.terms-of-use', compact('data'));
    }

    function contact(Request $request)
    {
        $data = Staticpage::find(2);
        return view('front.contact', compact('data'));
    }

    function contactsubmit(Request $request)
    {
        $data = $request->all();

        if ($request->isMethod('POST')) {            
            $token = $request->get('g-recaptcha-response');
            $result = Recaptcha::verify($token);
            if(!$result){
                return response()->json([
                    "redirect" => route('home'),
                ]);
            }
        }

        if (isset($data['attachment'])) {
            $upload_dir_path        = "uploads/attachments";
            $imagePath              = $data["attachment"];
            $extension              = pathinfo($imagePath->getClientOriginalName(), PATHINFO_EXTENSION);
            $filename               = time() . "attachment." . $extension;

            S3Upload::uploadFile($imagePath, "normal", $upload_dir_path, $filename);
            $imagePath->move($upload_dir_path, $filename);
            // $imagePath->move($upload_dir_path, $filename);

            $data['attachment'] = awsAsset('uploads/attachments/' . $filename);
        }
        $settings = Setting::find(1);
        Mail::to("support@kincrests.com")->send(new ContactFormMail($data));

        session()->flash("success", "Form submitted successfully. Our team will contact you.");

        return $success = [
            "success" => "Mail send successfully."
        ];
    }

    function subscribeEmail(Request $request)
    {
        $mailchimp = new MailchimpService();
        $listId = "5d0f69a686";
        return $mailchimp->addSubscriber($request->email);
        // dd($mailchimp->getClient()->lists->getListMembersInfo($listId));

    }

    function setCookie(Request $request)
    {
        // $response = new Response('Permanent Cookie set successfully');
        $response = new RedirectResponse(url('/'));
        if ($request->status == "accepted") {
            $response->withCookie(cookie()->forever('cookiePermission', 'accepted'));
            // $response->cookie('cookiePermission', 'accepted' ,$minutes = 60*24*365);

        }

        // Set the expiration time to a large value (e.g., 1 year)

        return $response;
    }

    function faq(Request $request)
    {
        $data = Staticpage::find(5);
        $categories = FAQCategory::select('id', 'name')->get();
         
        return view('front.faq', compact('data', 'categories'));
    }

    function becomeARetail(Request $request)
    {
        $data = Staticpage::find(2);
        return view('front.become-a-retail', compact('data'));
    }

    function becomeARetailSubmit(Request $request)
    {
        $data = $request->all();

        if ($request->isMethod('POST')) {            
            $token = $request->get('g-recaptcha-response');
            $result = Recaptcha::verify($token);
            if(!$result){
                return response()->json([
                    "redirect" => route('home'),
                ]);
            }
        }

        try {
            if (isset($data['attachment'])) {
                $upload_dir_path        = "uploads/attachments";
                $imagePath              = $data["attachment"];
                $extension              = pathinfo($imagePath->getClientOriginalName(), PATHINFO_EXTENSION);
                $filename               = time() . "attachment." . $extension;

                S3Upload::uploadFile($imagePath, "normal", $upload_dir_path, $filename);
                $imagePath->move($upload_dir_path, $filename);

                $data['attachment'] = awsAsset('uploads/attachments/' . $filename);
            }
            $settings = Setting::find(1);
            Mail::to("info@kincrests.com")->send(new BecomeARetailer($data));

            session()->flash("success", "Form submitted successfully. Our retail team will contact you.");

            return response()->json([
                "success" => "Mail send successfully."
            ]);

        } catch (Exception $e) {
            return response()->json([
                "error" => $e->getMessage()
            ]);
        }
    }

   
}
